OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "New note" : "New note",
    "Note is currently saving. Leaving the page will delete all changes!" : "Note is currently saving. Leaving the page will delete all changes!",
    "_%n word_::_%n words_" : ["%n word","%n words"],
    "Delete note" : "Delete note",
    "Favorite" : "Favourite",
    "No notes found" : "No notes found"
},
"nplurals=2; plural=(n != 1);");
